@@ -5,31 +5,31 @@
 #include <osmium/io/file.hpp>
 
 TEST_CASE("Default file format") {
-    osmium::io::File f;
+    const osmium::io::File f;
     REQUIRE(osmium::io::file_format::unknown == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
     REQUIRE(false == f.has_multiple_object_versions());
-    REQUIRE_THROWS_AS(f.check(), std::runtime_error);
+    REQUIRE_THROWS_AS(f.check(), const std::runtime_error&);
 }
 
 TEST_CASE("File format when empty (stdin/stdout)") {
-    osmium::io::File f{""};
+    const osmium::io::File f{""};
     REQUIRE(osmium::io::file_format::unknown == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
     REQUIRE(false == f.has_multiple_object_versions());
-    REQUIRE_THROWS_AS(f.check(), std::runtime_error);
+    REQUIRE_THROWS_AS(f.check(), const std::runtime_error&);
 }
 
 TEST_CASE("File format from dash (stdin/stdout)") {
-    osmium::io::File f{"-"};
+    const osmium::io::File f{"-"};
     REQUIRE(osmium::io::file_format::unknown == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
     REQUIRE(false == f.has_multiple_object_versions());
-    REQUIRE_THROWS_AS(f.check(), std::runtime_error);
+    REQUIRE_THROWS_AS(f.check(), const std::runtime_error&);
 }
 
 TEST_CASE("File format from dash with osm.bz2") {
-    osmium::io::File f{"-", "osm.bz2"};
+    const osmium::io::File f{"-", "osm.bz2"};
     REQUIRE("" == f.filename());
     REQUIRE(osmium::io::file_format::xml == f.format());
     REQUIRE(osmium::io::file_compression::bzip2 == f.compression());
@@ -38,7 +38,7 @@ TEST_CASE("File format from dash with osm.bz2") {
 }
 
 TEST_CASE("Detect file format by suffix 'osm'") {
-    osmium::io::File f{"test.osm"};
+    const osmium::io::File f{"test.osm"};
     REQUIRE(osmium::io::file_format::xml == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
     REQUIRE(false == f.has_multiple_object_versions());
@@ -46,7 +46,7 @@ TEST_CASE("Detect file format by suffix 'osm'") {
 }
 
 TEST_CASE("Detect file format by suffix 'pbf'") {
-    osmium::io::File f{"test.pbf"};
+    const osmium::io::File f{"test.pbf"};
     REQUIRE(osmium::io::file_format::pbf == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
     REQUIRE(false == f.has_multiple_object_versions());
@@ -54,7 +54,7 @@ TEST_CASE("Detect file format by suffix 'pbf'") {
 }
 
 TEST_CASE("Detect file format by suffix 'osm.pbf'") {
-    osmium::io::File f{"test.osm.pbf"};
+    const osmium::io::File f{"test.osm.pbf"};
     REQUIRE(osmium::io::file_format::pbf == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
     REQUIRE(false == f.has_multiple_object_versions());
@@ -62,7 +62,7 @@ TEST_CASE("Detect file format by suffix 'osm.pbf'") {
 }
 
 TEST_CASE("Detect file format by suffix 'opl'") {
-    osmium::io::File f{"test.opl"};
+    const osmium::io::File f{"test.opl"};
     REQUIRE(osmium::io::file_format::opl == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
     REQUIRE(false == f.has_multiple_object_versions());
@@ -70,7 +70,7 @@ TEST_CASE("Detect file format by suffix 'opl'") {
 }
 
 TEST_CASE("Detect file format by suffix 'osm.opl'") {
-    osmium::io::File f{"test.osm.opl"};
+    const osmium::io::File f{"test.osm.opl"};
     REQUIRE(osmium::io::file_format::opl == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
     REQUIRE(false == f.has_multiple_object_versions());
@@ -78,7 +78,7 @@ TEST_CASE("Detect file format by suffix 'osm.opl'") {
 }
 
 TEST_CASE("Detect file format by suffix 'osm.gz'") {
-    osmium::io::File f{"test.osm.gz"};
+    const osmium::io::File f{"test.osm.gz"};
     REQUIRE(osmium::io::file_format::xml == f.format());
     REQUIRE(osmium::io::file_compression::gzip == f.compression());
     REQUIRE(false == f.has_multiple_object_versions());
@@ -86,7 +86,7 @@ TEST_CASE("Detect file format by suffix 'osm.gz'") {
 }
 
 TEST_CASE("Detect file format by suffix 'opl.bz2'") {
-    osmium::io::File f{"test.osm.opl.bz2"};
+    const osmium::io::File f{"test.osm.opl.bz2"};
     REQUIRE(osmium::io::file_format::opl == f.format());
     REQUIRE(osmium::io::file_compression::bzip2 == f.compression());
     REQUIRE(false == f.has_multiple_object_versions());
@@ -94,7 +94,7 @@ TEST_CASE("Detect file format by suffix 'opl.bz2'") {
 }
 
 TEST_CASE("Detect file format by suffix 'osc.gz'") {
-    osmium::io::File f{"test.osc.gz"};
+    const osmium::io::File f{"test.osc.gz"};
     REQUIRE(osmium::io::file_format::xml == f.format());
     REQUIRE(osmium::io::file_compression::gzip == f.compression());
     REQUIRE(true == f.has_multiple_object_versions());
@@ -102,7 +102,7 @@ TEST_CASE("Detect file format by suffix 'osc.gz'") {
 }
 
 TEST_CASE("Detect file format by suffix 'opl.gz'") {
-    osmium::io::File f{"test.osh.opl.gz"};
+    const osmium::io::File f{"test.osh.opl.gz"};
     REQUIRE(osmium::io::file_format::opl == f.format());
     REQUIRE(osmium::io::file_compression::gzip == f.compression());
     REQUIRE(true == f.has_multiple_object_versions());
@@ -110,7 +110,7 @@ TEST_CASE("Detect file format by suffix 'opl.gz'") {
 }
 
 TEST_CASE("Detect file format by suffix 'osh.pbf'") {
-    osmium::io::File f{"test.osh.pbf"};
+    const osmium::io::File f{"test.osh.pbf"};
     REQUIRE(osmium::io::file_format::pbf == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
     REQUIRE(true == f.has_multiple_object_versions());
@@ -118,7 +118,7 @@ TEST_CASE("Detect file format by suffix 'osh.pbf'") {
 }
 
 TEST_CASE("Override file format by suffix 'osm'") {
-    osmium::io::File f{"test", "osm"};
+    const osmium::io::File f{"test", "osm"};
     REQUIRE(osmium::io::file_format::xml == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
     REQUIRE(false == f.has_multiple_object_versions());
@@ -126,7 +126,7 @@ TEST_CASE("Override file format by suffix 'osm'") {
 }
 
 TEST_CASE("Override file format by suffix 'pbf'") {
-    osmium::io::File f{"test", "pbf"};
+    const osmium::io::File f{"test", "pbf"};
     REQUIRE(osmium::io::file_format::pbf == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
     REQUIRE(false == f.has_multiple_object_versions());
@@ -134,7 +134,7 @@ TEST_CASE("Override file format by suffix 'pbf'") {
 }
 
 TEST_CASE("Override file format by suffix 'osm.pbf'") {
-    osmium::io::File f{"test", "osm.pbf"};
+    const osmium::io::File f{"test", "osm.pbf"};
     REQUIRE(osmium::io::file_format::pbf == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
     REQUIRE(false == f.has_multiple_object_versions());
@@ -142,7 +142,7 @@ TEST_CASE("Override file format by suffix 'osm.pbf'") {
 }
 
 TEST_CASE("Override file format by suffix 'opl'") {
-    osmium::io::File f{"test", "opl"};
+    const osmium::io::File f{"test", "opl"};
     REQUIRE(osmium::io::file_format::opl == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
     REQUIRE(false == f.has_multiple_object_versions());
@@ -150,7 +150,7 @@ TEST_CASE("Override file format by suffix 'opl'") {
 }
 
 TEST_CASE("Override file format by suffix 'osm.opl'") {
-    osmium::io::File f{"test", "osm.opl"};
+    const osmium::io::File f{"test", "osm.opl"};
     REQUIRE(osmium::io::file_format::opl == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
     REQUIRE(false == f.has_multiple_object_versions());
@@ -158,7 +158,7 @@ TEST_CASE("Override file format by suffix 'osm.opl'") {
 }
 
 TEST_CASE("Override file format by suffix 'osm.gz'") {
-    osmium::io::File f{"test", "osm.gz"};
+    const osmium::io::File f{"test", "osm.gz"};
     REQUIRE(osmium::io::file_format::xml == f.format());
     REQUIRE(osmium::io::file_compression::gzip == f.compression());
     REQUIRE(false == f.has_multiple_object_versions());
@@ -166,7 +166,7 @@ TEST_CASE("Override file format by suffix 'osm.gz'") {
 }
 
 TEST_CASE("Override file format by suffix 'osm.opl.bz2'") {
-    osmium::io::File f{"test", "osm.opl.bz2"};
+    const osmium::io::File f{"test", "osm.opl.bz2"};
     REQUIRE(osmium::io::file_format::opl == f.format());
     REQUIRE(osmium::io::file_compression::bzip2 == f.compression());
     REQUIRE(false == f.has_multiple_object_versions());
@@ -174,7 +174,7 @@ TEST_CASE("Override file format by suffix 'osm.opl.bz2'") {
 }
 
 TEST_CASE("Override file format by suffix 'osc.gz'") {
-    osmium::io::File f{"test", "osc.gz"};
+    const osmium::io::File f{"test", "osc.gz"};
     REQUIRE(osmium::io::file_format::xml == f.format());
     REQUIRE(osmium::io::file_compression::gzip == f.compression());
     REQUIRE(true == f.has_multiple_object_versions());
@@ -182,7 +182,7 @@ TEST_CASE("Override file format by suffix 'osc.gz'") {
 }
 
 TEST_CASE("Override file format by suffix 'osh.opl.gz'") {
-    osmium::io::File f{"test", "osh.opl.gz"};
+    const osmium::io::File f{"test", "osh.opl.gz"};
     REQUIRE(osmium::io::file_format::opl == f.format());
     REQUIRE(osmium::io::file_compression::gzip == f.compression());
     REQUIRE(true == f.has_multiple_object_versions());
@@ -190,7 +190,7 @@ TEST_CASE("Override file format by suffix 'osh.opl.gz'") {
 }
 
 TEST_CASE("Override file format by suffix 'osh.pbf'") {
-    osmium::io::File f{"test", "osh.pbf"};
+    const osmium::io::File f{"test", "osh.pbf"};
     REQUIRE(osmium::io::file_format::pbf == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
     REQUIRE(true == f.has_multiple_object_versions());
@@ -198,7 +198,7 @@ TEST_CASE("Override file format by suffix 'osh.pbf'") {
 }
 
 TEST_CASE("Format option pbf history") {
-    osmium::io::File f{"test", "pbf,history=true"};
+    const osmium::io::File f{"test", "pbf,history=true"};
     REQUIRE(osmium::io::file_format::pbf == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
     REQUIRE(true == f.has_multiple_object_versions());
@@ -206,7 +206,7 @@ TEST_CASE("Format option pbf history") {
 }
 
 TEST_CASE("Format option pbf foo") {
-    osmium::io::File f{"test.osm", "pbf,foo=bar"};
+    const osmium::io::File f{"test.osm", "pbf,foo=bar"};
     REQUIRE(osmium::io::file_format::pbf == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
     REQUIRE("bar" == f.get("foo"));
@@ -214,7 +214,7 @@ TEST_CASE("Format option pbf foo") {
 }
 
 TEST_CASE("Format option xml abc something") {
-    osmium::io::File f{"test.bla", "xml,abc,some=thing"};
+    const osmium::io::File f{"test.bla", "xml,abc,some=thing"};
     REQUIRE(osmium::io::file_format::xml == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
     REQUIRE("true" == f.get("abc"));
@@ -224,29 +224,29 @@ TEST_CASE("Format option xml abc something") {
 }
 
 TEST_CASE("Unknown format 'foo.bar'") {
-    osmium::io::File f{"test.foo.bar"};
+    const osmium::io::File f{"test.foo.bar"};
     REQUIRE(osmium::io::file_format::unknown == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
-    REQUIRE_THROWS_AS(f.check(), std::runtime_error);
+    REQUIRE_THROWS_AS(f.check(), const std::runtime_error&);
 }
 
 TEST_CASE("Unknown format 'foo'") {
-    osmium::io::File f{"test", "foo"};
-    REQUIRE_THROWS_AS(f.check(), std::runtime_error);
+    const osmium::io::File f{"test", "foo"};
+    REQUIRE_THROWS_AS(f.check(), const std::runtime_error&);
 }
 
 TEST_CASE("Unknown format 'osm.foo'") {
-    osmium::io::File f{"test", "osm.foo"};
-    REQUIRE_THROWS_AS(f.check(), std::runtime_error);
+    const osmium::io::File f{"test", "osm.foo"};
+    REQUIRE_THROWS_AS(f.check(), const std::runtime_error&);
 }
 
 TEST_CASE("Unknown format 'bla=foo'") {
-    osmium::io::File f{"test", "bla=foo"};
-    REQUIRE_THROWS_AS(f.check(), std::runtime_error);
+    const osmium::io::File f{"test", "bla=foo"};
+    REQUIRE_THROWS_AS(f.check(), const std::runtime_error&);
 }
 
 TEST_CASE("URL without format") {
-    osmium::io::File f{"http://www.example.com/api"};
+    const osmium::io::File f{"http://www.example.com/api"};
     REQUIRE(osmium::io::file_format::xml == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
     REQUIRE(false == f.has_multiple_object_versions());
@@ -254,7 +254,7 @@ TEST_CASE("URL without format") {
 }
 
 TEST_CASE("URL without format and filename") {
-    osmium::io::File f{"http://planet.osm.org/pbf/planet-latest.osm.pbf"};
+    const osmium::io::File f{"http://planet.osm.org/pbf/planet-latest.osm.pbf"};
     REQUIRE(osmium::io::file_format::pbf == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
     REQUIRE(false == f.has_multiple_object_versions());
@@ -262,7 +262,7 @@ TEST_CASE("URL without format and filename") {
 }
 
 TEST_CASE("URL with format") {
-    osmium::io::File f{"http://www.example.com/api", "osh"};
+    const osmium::io::File f{"http://www.example.com/api", "osh"};
     REQUIRE(osmium::io::file_format::xml == f.format());
     REQUIRE(osmium::io::file_compression::none == f.compression());
     REQUIRE(true == f.has_multiple_object_versions());
